@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -178,6 +178,10 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     connect(m_cancelButton, &QAbstractButton::clicked,
             this, &QWidget::hide);
 
+    m_bottomButtonBox = new QDialogButtonBox(this);
+    m_bottomButtonBox->addButton(m_saveButton,   QDialogButtonBox::AcceptRole);
+    m_bottomButtonBox->addButton(m_cancelButton, QDialogButtonBox::RejectRole);
+
 
     // Unlock button, visible when the account is already authorized, + info
     m_unlockExplanationLabel = new QLabel("<b>"
@@ -215,11 +219,6 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     m_verifierLayout->addWidget(m_authorizeButton);
 
 
-    m_buttonsLayout = new QHBoxLayout();
-    m_buttonsLayout->setAlignment(Qt::AlignRight);
-    m_buttonsLayout->addWidget(m_saveButton);
-    m_buttonsLayout->addWidget(m_cancelButton);
-
 
     m_mainLayout = new QVBoxLayout();
     m_mainLayout->addWidget(m_unlockExplanationLabel, 6);
@@ -243,7 +242,7 @@ AccountDialog::AccountDialog(PumpController *pumpController, QWidget *parent) :
     m_mainLayout->addWidget(m_authorizationStatusLabel, 1, Qt::AlignCenter);
     m_mainLayout->addStretch(2);
     m_mainLayout->addSpacing(8);
-    m_mainLayout->addLayout(m_buttonsLayout, 1);
+    m_mainLayout->addWidget(m_bottomButtonBox, 1);
     this->setLayout(m_mainLayout);
 
 
