@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
+#include <QDialogButtonBox>
 #include <QByteArray>
 #include <QHideEvent>
 
@@ -63,9 +64,11 @@ public slots:
 
     void unlockDialog();
 
+
 protected:
     virtual void hideEvent(QHideEvent *event);
 
+
 private:
     QVBoxLayout *m_mainLayout;
 
@@ -94,7 +97,7 @@ private:
     QLabel *m_unlockExplanationLabel;
     QPushButton *m_unlockButton;
 
-    QHBoxLayout *m_buttonsLayout;
+    QDialogButtonBox *m_bottomButtonBox;
     QPushButton *m_saveButton;
     QPushButton *m_cancelButton;
 
