@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -238,7 +238,7 @@ QString ASActivity::getToString()
     return m_recipientsToString;
 }
 
-QString ASActivity::getCCString()
+QString ASActivity::getCcString()
 {
     return m_recipientsCcString;
 }
