@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,16 +22,15 @@
 
 
 DownloadWidget::DownloadWidget(QString fileUrl,
-                               QString suggestedFilename,
                                PumpController *pumpController,
                                QWidget *parent) : QFrame(parent)
 {
     m_pumpController = pumpController;
     m_fileUrl = fileUrl;
-    m_suggestedFilename = suggestedFilename;
 
     this->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
     m_downloading = false;
+    m_aborted = false;
 
 
     QFont infoFont;
@@ -116,6 +115,13 @@ void DownloadWidget::resetWidget()
     m_downloadedFile.close();
 
     m_downloading = false;
+    m_aborted = false;
+}
+
+
+void DownloadWidget::updateSuggestedFilename(QString newFilename)
+{
+    m_suggestedFilename = newFilename;
 }
 
 
@@ -210,9 +216,13 @@ void DownloadWidget::cancelDownload()
 
     if (confirmation == 0)
     {
+        m_aborted = true;
         m_networkReply->abort();
 
-        m_infoLabel->setText(tr("Download aborted"));
+        const QString abortMessage = tr("Download aborted");
+        m_infoLabel->setText(abortMessage);
+        m_pumpController->showStatusMessageAndLogIt(abortMessage
+                                                    + QStringLiteral("."));
         resetWidget();
     }
     else
@@ -224,7 +234,8 @@ void DownloadWidget::cancelDownload()
 
 void DownloadWidget::completeDownload(QString url)
 {
-    if (url == m_fileUrl) // Ensure completed download is this download
+    if (url == m_fileUrl  // Ensure completed download is this download
+     && !m_aborted)       // And wasn't aborted
     {
         m_infoLabel->setText(tr("Download completed"));
         resetWidget(); // This also closes the file
