@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -78,6 +78,9 @@ EmailChanger::EmailChanger(QString explanation,
     connect(m_cancelButton, &QAbstractButton::clicked,
             this, &EmailChanger::cancelDialog);
 
+    m_bottomButtonBox = new QDialogButtonBox(this);
+    m_bottomButtonBox->addButton(m_changeButton, QDialogButtonBox::AcceptRole);
+    m_bottomButtonBox->addButton(m_cancelButton, QDialogButtonBox::RejectRole);
 
 
     // ESC to cancel, too
@@ -95,11 +98,6 @@ EmailChanger::EmailChanger(QString explanation,
     m_middleLayout->addRow(tr("Again:"),          m_mailRepeatLineEdit);
     m_middleLayout->addRow(tr("Your Password:"),  m_passwordLineEdit);
 
-    m_bottomLayout = new QHBoxLayout();
-    m_bottomLayout->setAlignment(Qt::AlignRight);
-    m_bottomLayout->addWidget(m_changeButton);
-    m_bottomLayout->addWidget(m_cancelButton);
-
     m_mainLayout = new QVBoxLayout();
     m_mainLayout->addWidget(m_infoLabel);
     m_mainLayout->addSpacing(8);
@@ -109,7 +107,7 @@ EmailChanger::EmailChanger(QString explanation,
     m_mainLayout->addWidget(m_errorsLabel, 2);
     m_mainLayout->addStretch(1);
     m_mainLayout->addSpacing(8);
-    m_mainLayout->addLayout(m_bottomLayout);
+    m_mainLayout->addWidget(m_bottomButtonBox);
     this->setLayout(m_mainLayout);
 
     qDebug() << "EmailChanger created";
