@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -25,8 +25,8 @@
 #include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
+#include <QDialogButtonBox>
 #include <QFormLayout>
-#include <QHBoxLayout>
 #include <QAction>
 #include <QCloseEvent>
 
@@ -64,7 +64,7 @@ protected:
 private:
     QVBoxLayout *m_mainLayout;
     QFormLayout *m_middleLayout;
-    QHBoxLayout *m_bottomLayout;
+    QDialogButtonBox *m_bottomButtonBox;
 
     QLabel *m_infoLabel;
 
