@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -46,12 +46,15 @@ void FilterChecker::setFilters(QVariantList newFiltersList)
     // Define new filter values
     foreach (QVariant filter, newFiltersList)
     {
-        QString actionType = filter.toMap().value("action").toString();
-        int filterType = filter.toMap().value("type").toInt();
-        QString filterText = filter.toMap().value("text").toString();
+        const int filterType = filter.toMap().value(QStringLiteral("type"))
+                                             .toInt();
 
-        QStringList pair;
-        pair << filterText << actionType;
+        QStringList pair = QStringList{ filter.toMap()
+                                              .value(QStringLiteral("text"))
+                                              .toString(),
+                                        filter.toMap()
+                                              .value(QStringLiteral("action"))
+                                              .toString() };
 
         switch (filterType)
         {
@@ -156,11 +159,16 @@ int FilterChecker::validateActivity(ASActivity *activity)
     }
 
 
-    filterMatches.insert("filterAction",        filterAction);
-    filterMatches.insert("matchingContent",     matchingContent);
-    filterMatches.insert("matchingAuthor",      matchingAuthor);
-    filterMatches.insert("matchingGenerator",   matchingGenerator);
-    filterMatches.insert("matchingDescription", matchingDescription);
+    filterMatches.insert(QStringLiteral("filterAction"),
+                         filterAction);
+    filterMatches.insert(QStringLiteral("matchingContent"),
+                         matchingContent);
+    filterMatches.insert(QStringLiteral("matchingAuthor"),
+                         matchingAuthor);
+    filterMatches.insert(QStringLiteral("matchingGenerator"),
+                         matchingGenerator);
+    filterMatches.insert(QStringLiteral("matchingDescription"),
+                         matchingDescription);
 
     activity->setFilterMatches(filterMatches);
 
