@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -134,6 +134,11 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
     connect(m_cancelButton, &QAbstractButton::clicked,
             this, &QWidget::hide);
 
+    m_bottomButtonBox = new QDialogButtonBox(this);
+    m_bottomButtonBox->addButton(m_saveButton,   QDialogButtonBox::AcceptRole);
+    m_bottomButtonBox->addButton(m_cancelButton, QDialogButtonBox::RejectRole);
+
+
     m_closeAction = new QAction(this);
     m_closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
     connect(m_closeAction, &QAction::triggered,
@@ -166,11 +171,6 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
     m_currentFiltersGroupBox->setLayout(m_middleLayout);
 
 
-    m_bottomLayout = new QHBoxLayout();
-    m_bottomLayout->setAlignment(Qt::AlignRight);
-    m_bottomLayout->addWidget(m_saveButton);
-    m_bottomLayout->addWidget(m_cancelButton);
-
     m_mainLayout = new QVBoxLayout();
     m_mainLayout->addWidget(m_explanationLabel);
     m_mainLayout->addSpacing(4);
@@ -178,7 +178,7 @@ FilterEditor::FilterEditor(FilterChecker *filterChecker,
     m_mainLayout->addSpacing(2);
     m_mainLayout->addWidget(m_currentFiltersGroupBox);
     m_mainLayout->addSpacing(8);
-    m_mainLayout->addLayout(m_bottomLayout);
+    m_mainLayout->addWidget(m_bottomButtonBox);
     this->setLayout(m_mainLayout);
 
 
