@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <QComboBox>
 #include <QLineEdit>
 #include <QPushButton>
+#include <QDialogButtonBox>
 #include <QListWidget>
 #include <QVariantList>
 #include <QVariantMap>
@@ -77,7 +78,7 @@ private:
     QGroupBox *m_newFilterGroupBox;
     QVBoxLayout *m_middleLayout;
     QGroupBox *m_currentFiltersGroupBox;
-    QHBoxLayout *m_bottomLayout;
+    QDialogButtonBox *m_bottomButtonBox;
 
     QAction *m_closeAction;
 
