@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -53,23 +53,23 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
 
 
     //////////////////////////////////////////////////////////////////// COLORS
-    this->colorsList.clear();                           // Defaults:
-    colorsList << settings.value("color1", "#CC2030").toString() // Red
-               << settings.value("color2", "#5599CC").toString() // Blue
-               << settings.value("color3", "#DDCC10").toString() // Yellow
-               << settings.value("color4", "#10BB10").toString() // Green
-               << settings.value("color5", "#AA77EE").toString() // Purple
-               << settings.value("color6").toString();
+    m_colorsList.clear();                                 // Defaults:
+    m_colorsList << settings.value("color1", "#CC2030").toString() // Red
+                 << settings.value("color2", "#5599CC").toString() // Blue
+                 << settings.value("color3", "#DDCC10").toString() // Yellow
+                 << settings.value("color4", "#10BB10").toString() // Green
+                 << settings.value("color5", "#AA77EE").toString() // Purple
+                 << settings.value("color6").toString();
     // No need to call this->syncColorSettings() here...
 
 
     ///////////////////////////////////////////////////////////////// TIMELINES
-    int pppMain = qBound(5,
-                         settings.value("postsPerPageMain", 20).toInt(),
-                         50);
-    int pppOther = qBound(1,
-                          settings.value("postsPerPageOther", 5).toInt(),
-                          30);
+    const int pppMain = qBound(5,
+                               settings.value("postsPerPageMain", 20).toInt(),
+                               50);
+    const int pppOther = qBound(1,
+                                settings.value("postsPerPageOther", 5).toInt(),
+                                30);
     this->syncTimelinesSettings(pppMain,
                                 pppOther,
                                 settings.value("showDeletedPosts",     false).toBool(),
@@ -78,13 +78,13 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
                                 settings.value("mfSnippetsType",       2).toInt(), // Default: Always
                                 settings.value("snippetCharLimit",     30).toInt(),
                                 settings.value("snippetCharLimitHl",   200).toInt(),
-                                settings.value("minorFeedAvatarIndex", 1).toInt(),  // Default: 2nd (32x32)
-                                settings.value("minorFeedIconType",    0).toInt()); // Default: No
+                                settings.value("minorFeedAvatarIndex", 1).toInt(),  // Def: 2nd (32x32)
+                                settings.value("minorFeedIconType",    0).toInt()); // Def: No
 
 
     ///////////////////////////////////////////////////////////////////// POSTS
-    this->syncPostSettings(settings.value("postAvatarIndex",       3).toInt(), // 4th (64x64) by default
-                           settings.value("commentAvatarIndex",    1).toInt(), // 2nd (32x32) by default
+    this->syncPostSettings(settings.value("postAvatarIndex",       3).toInt(), // Def: 4th (64x64)
+                           settings.value("commentAvatarIndex",    1).toInt(), // Def: 2nd (32x32)
                            settings.value("postExtendedShares",    true).toBool(),
                            settings.value("postShowExtraInfo",     false).toBool(),
                            settings.value("postHLAuthorComments",  true).toBool(),
@@ -112,27 +112,29 @@ GlobalObject::GlobalObject(QObject *parent) : QObject(parent)
 
 
     ////////////////////////////////////////////////////////////////////// TRAY
-    this->syncTrayOptions(settings.value("systrayHideInTray", false).toBool());
-                                          // TODO: load the other tray options
+    this->syncTrayOptions(settings.value("systrayIconType", 0).toInt(),
+                          settings.value("systrayCustomIconFN").toString(),
+                          settings.value("systrayHideInTray", false).toBool());
 
 
     settings.endGroup();
 
+    ///////////////////////////////////////////////////////////////////////////
 
     // Model for nick completion used by Composer
-    this->nickCompletionModel = new QStandardItemModel(this);
-    nickCompletionModel->setColumnCount(2);
+    m_nickCompletionModel = new QStandardItemModel(this);
+    m_nickCompletionModel->setColumnCount(2);
 
-    this->filterCompletionModel = new QSortFilterProxyModel(this);
-    filterCompletionModel->setSortCaseSensitivity(Qt::CaseInsensitive);
-    filterCompletionModel->setSourceModel(nickCompletionModel);
+    m_filterCompletionModel = new QSortFilterProxyModel(this);
+    m_filterCompletionModel->setSortCaseSensitivity(Qt::CaseInsensitive);
+    m_filterCompletionModel->setSourceModel(m_nickCompletionModel);
 
 
     // Timeline height used to calculate maximum optimal height for post contents
-    this->timelineHeight = 400; // Some initial value
+    m_timelineHeight = 400; // Some initial value
 
 
-    this->programClosing = false;
+    m_programIsClosing = false;
 
     qDebug() << "GlobalObject created";
 }
@@ -158,55 +160,55 @@ void GlobalObject::syncFontSettings(QString postTitleFont,
                                     QString commentsFont,
                                     QString minorFeedFont)
 {
-    this->postTitleFontInfo = postTitleFont;
-    this->postContentsFontInfo = postContentsFont;
-    this->commentsFontInfo = commentsFont;
-    this->minorFeedFontInfo = minorFeedFont;
+    m_postTitleFontInfo = postTitleFont;
+    m_postContentsFontInfo = postContentsFont;
+    m_commentsFontInfo = commentsFont;
+    m_minorFeedFontInfo = minorFeedFont;
 
     qDebug() << "GlobalObject::syncFontSettings() - font info sync'd";
 }
 
 QString GlobalObject::getPostTitleFont()
 {
-    return this->postTitleFontInfo;
+    return m_postTitleFontInfo;
 }
 
 QString GlobalObject::getPostContentsFont()
 {
-    return this->postContentsFontInfo;
+    return m_postContentsFontInfo;
 }
 
 QString GlobalObject::getCommentsFont()
 {
-    return this->commentsFontInfo;
+    return m_commentsFontInfo;
 }
 
 QString GlobalObject::getMinorFeedFont()
 {
-    return this->minorFeedFontInfo;
+    return m_minorFeedFontInfo;
 }
 
 
 // Color options
 void GlobalObject::syncColorSettings(QStringList newColorList)
 {
-    this->colorsList = newColorList;
+    m_colorsList = newColorList;
 
     qDebug() << "GlobalObject::syncColorSettings() - color list sync'd";
 }
 
 QStringList GlobalObject::getColorsList()
 {
-    return this->colorsList;
+    return m_colorsList;
 }
 
 QString GlobalObject::getColor(int colorIndex)
 {
     QString color;
 
-    if (colorIndex >= 0 && colorIndex < this->colorsList.length())
+    if (colorIndex >= 0 && colorIndex < m_colorsList.length())
     {
-        color = this->colorsList.at(colorIndex);
+        color = m_colorsList.at(colorIndex);
         if (!QColor::isValidColor(color)) // If invalid, clear it
         {
             color.clear();
@@ -222,150 +224,150 @@ void GlobalObject::syncTimelinesSettings(int pppMain, int pppOther,
                                          bool showDeleted, bool hideDuplicates,
                                          bool jumpToNew, int minorFeedSnippets,
                                          int snippetsChars, int snippetsCharsHl,
-                                         int mfAvatarIdx, int mfVerbIconType)
+                                         int mfAvatarIndex, int mfVerbIconType)
 {
-    this->postsPerPageMain = pppMain;
-    this->postsPerPageOther = pppOther;
+    m_postsPerPageMain = pppMain;
+    m_postsPerPageOther = pppOther;
 
-    this->showDeletedPosts = showDeleted;
-    this->hideDuplicatedPosts = hideDuplicates;
-    this->jumpToNewOnUpdate = jumpToNew;
+    m_showDeletedPosts = showDeleted;
+    m_hideDuplicatedPosts = hideDuplicates;
+    m_jumpToNewOnUpdate = jumpToNew;
 
-    this->minorFeedSnippetsType = minorFeedSnippets;
-    this->snippetsCharLimit = snippetsChars;
-    this->snippetsCharLimitHl = snippetsCharsHl;
-    this->mfAvatarIndex = mfAvatarIdx;
-    this->mfAvatarSize = this->getAvatarSizeForIndex(mfAvatarIdx);
+    m_minorFeedSnippetsType = minorFeedSnippets;
+    m_snippetsCharLimit = snippetsChars;
+    m_snippetsCharLimitHl = snippetsCharsHl;
+    m_mfAvatarIndex = mfAvatarIndex;
+    m_mfAvatarSize = this->getAvatarSizeForIndex(mfAvatarIndex);
 
-    this->mfIconType = mfVerbIconType;
+    m_mfIconType = mfVerbIconType;
 
     // TODO: more...
 }
 
 int GlobalObject::getPostsPerPageMain()
 {
-    return this->postsPerPageMain;
+    return m_postsPerPageMain;
 }
 
 int GlobalObject::getPostsPerPageOther()
 {
-    return this->postsPerPageOther;
+    return m_postsPerPageOther;
 }
 
 bool GlobalObject::getShowDeleted()
 {
-    return this->showDeletedPosts;
+    return m_showDeletedPosts;
 }
 
 bool GlobalObject::getHideDuplicates()
 {
-    return this->hideDuplicatedPosts;
+    return m_hideDuplicatedPosts;
 }
 
 bool GlobalObject::getJumpToNewOnUpdate()
 {
-    return this->jumpToNewOnUpdate;
+    return m_jumpToNewOnUpdate;
 }
 
 int GlobalObject::getMinorFeedSnippetsType()
 {
-    return this->minorFeedSnippetsType;
+    return m_minorFeedSnippetsType;
 }
 
 int GlobalObject::getSnippetsCharLimit()
 {
-    return this->snippetsCharLimit;
+    return m_snippetsCharLimit;
 }
 
 int GlobalObject::getSnippetsCharLimitHl()
 {
-    return this->snippetsCharLimitHl;
+    return m_snippetsCharLimitHl;
 }
 
 int GlobalObject::getMfAvatarIndex()
 {
-    return this->mfAvatarIndex;
+    return m_mfAvatarIndex;
 }
 
 QSize GlobalObject::getMfAvatarSize()
 {
-    return this->mfAvatarSize;
+    return m_mfAvatarSize;
 }
 
 int GlobalObject::getMfIconType()
 {
-    return this->mfIconType;
+    return m_mfIconType;
 }
 
 
 
 // Post options
-void GlobalObject::syncPostSettings(int postAvatarIdx, int commentAvatarIdx,
+void GlobalObject::syncPostSettings(int postAvatarIndex, int commentAvatarIndex,
                                     bool extendedShares, bool showExtraInfo,
                                     bool hlAuthorComments, bool hlOwnComments,
                                     bool ignoreSslInImages, bool fullImages)
 {
-    this->postAvatarIndex = postAvatarIdx;
-    this->postAvatarSize = this->getAvatarSizeForIndex(postAvatarIdx);
-    this->commentAvatarIndex = commentAvatarIdx;
-    this->commentAvatarSize = this->getAvatarSizeForIndex(commentAvatarIdx);
+    m_postAvatarIndex = postAvatarIndex;
+    m_postAvatarSize = this->getAvatarSizeForIndex(postAvatarIndex);
+    m_commentAvatarIndex = commentAvatarIndex;
+    m_commentAvatarSize = this->getAvatarSizeForIndex(commentAvatarIndex);
 
-    this->postExtendedShares = extendedShares;
-    this->postShowExtraInfo = showExtraInfo;
-    this->postHLAuthorComments = hlAuthorComments;
-    this->postHLOwnComments = hlOwnComments;
-    this->postIgnoreSslInImages = ignoreSslInImages;
-    this->postFullImages = fullImages;
+    m_postExtendedShares = extendedShares;
+    m_postShowExtraInfo = showExtraInfo;
+    m_postHLAuthorComments = hlAuthorComments;
+    m_postHLOwnComments = hlOwnComments;
+    m_postIgnoreSslInImages = ignoreSslInImages;
+    m_postFullImages = fullImages;
 }
 
 int GlobalObject::getPostAvatarIndex()
 {
-    return this->postAvatarIndex;
+    return m_postAvatarIndex;
 }
 
 QSize GlobalObject::getPostAvatarSize()
 {
-    return this->postAvatarSize;
+    return m_postAvatarSize;
 }
 
 int GlobalObject::getCommentAvatarIndex()
 {
-    return this->commentAvatarIndex;
+    return m_commentAvatarIndex;
 }
 
 QSize GlobalObject::getCommentAvatarSize()
 {
-    return this->commentAvatarSize;
+    return m_commentAvatarSize;
 }
 
 bool GlobalObject::getPostExtendedShares()
 {
-    return this->postExtendedShares;
+    return m_postExtendedShares;
 }
 
 bool GlobalObject::getPostShowExtraInfo()
 {
-    return this->postShowExtraInfo;
+    return m_postShowExtraInfo;
 }
 
 bool GlobalObject::getPostHLAuthorComments()
 {
-    return this->postHLAuthorComments;
+    return m_postHLAuthorComments;
 }
 
 bool GlobalObject::getPostHLOwnComments()
 {
-    return this->postHLOwnComments;
+    return m_postHLOwnComments;
 }
 
 bool GlobalObject::getPostIgnoreSslInImages()
 {
-    return this->postIgnoreSslInImages;
+    return m_postIgnoreSslInImages;
 }
 
 bool GlobalObject::getPostFullImages()
 {
-    return this->postFullImages;
+    return m_postFullImages;
 }
 
 
@@ -374,24 +376,24 @@ void GlobalObject::syncComposerSettings(bool publicPosts,
                                         bool filenameAsTitle,
                                         bool showCharCounter)
 {
-    this->publicPostsByDefault = publicPosts;
-    this->useFilenameAsTitle = filenameAsTitle;
-    this->showCharacterCounter = showCharCounter;
+    m_publicPostsByDefault = publicPosts;
+    m_useFilenameAsTitle = filenameAsTitle;
+    m_showCharacterCounter = showCharCounter;
 }
 
 bool GlobalObject::getPublicPostsByDefault()
 {
-    return this->publicPostsByDefault;
+    return m_publicPostsByDefault;
 }
 
 bool GlobalObject::getUseFilenameAsTitle()
 {
-    return this->useFilenameAsTitle;
+    return m_useFilenameAsTitle;
 }
 
 bool GlobalObject::getShowCharacterCounter()
 {
-    return this->showCharacterCounter;
+    return m_showCharacterCounter;
 }
 
 
@@ -400,55 +402,66 @@ bool GlobalObject::getShowCharacterCounter()
 void GlobalObject::syncPrivacySettings(bool silentFollows, bool silentLists,
                                        bool silentLikes)
 {
-    this->silentFollowing = silentFollows;
-    this->silentListsHandling = silentLists;
-    this->silentLiking = silentLikes;
+    m_silentFollowing = silentFollows;
+    m_silentListsHandling = silentLists;
+    m_silentLiking = silentLikes;
 }
 
 bool GlobalObject::getSilentFollows()
 {
-    return this->silentFollowing;
+    return m_silentFollowing;
 }
 
 bool GlobalObject::getSilentLists()
 {
-    return this->silentListsHandling;
+    return m_silentListsHandling;
 }
 
 bool GlobalObject::getSilentLikes()
 {
-    return this->silentLiking;
+    return m_silentLiking;
 }
 
 
 
 // Notification options
-void GlobalObject::syncNotificationSettings(bool notifyTaskbar)
+void GlobalObject::syncNotificationSettings(bool notifyInTaskbar)
 {
-    this->notifyInTaskbar = notifyTaskbar;
+    m_notifyInTaskbar = notifyInTaskbar;
 
     // TODO, most still handled elsewhere
 }
 
 bool GlobalObject::getNotifyInTaskbar()
 {
-    return this->notifyInTaskbar;
+    return m_notifyInTaskbar;
 }
 
 
 
 // Tray options
-void GlobalObject::syncTrayOptions(bool hideInTrayStartup)
+void GlobalObject::syncTrayOptions(int trayIconType, QString trayIconFN,
+                                   bool trayHideStartup)
 {
-    this->hideInTray = hideInTrayStartup;
-
-    // TODO, some still handled elsewhere
+    m_systrayIconType = trayIconType;
+    m_systrayIconFN = trayIconFN;
+    m_systrayHideStartup = trayHideStartup;
 }
 
 
-bool GlobalObject::getHideInTray()
+int GlobalObject::getTrayIconType()
 {
-    return this->hideInTray;
+    return m_systrayIconType;
+}
+
+QString GlobalObject::getTrayIconFilename()
+{
+    return m_systrayIconFN;
+}
+
+bool GlobalObject::getTrayHideOnStartup()
+{
+    return m_systrayHideStartup;
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -456,12 +469,12 @@ bool GlobalObject::getHideInTray()
 
 void GlobalObject::setDataDirectory(QString dataDir)
 {
-    this->dataDirectory = dataDir;
+    m_dataDirectory = dataDir;
 }
 
 QString GlobalObject::getDataDirectory()
 {
-    return this->dataDirectory;
+    return m_dataDirectory;
 }
 
 
@@ -506,7 +519,7 @@ void GlobalObject::editPost(QString originalPostId,
 
 QSortFilterProxyModel *GlobalObject::getNickCompletionModel()
 {
-    return this->filterCompletionModel;
+    return m_filterCompletionModel;
 }
 
 
@@ -523,7 +536,7 @@ void GlobalObject::addToNickCompletionModel(QString id, QString name,
     itemLine.append(itemName);
     itemLine.append(itemId);
 
-    this->nickCompletionModel->appendRow(itemLine);
+    m_nickCompletionModel->appendRow(itemLine);
 }
 
 void GlobalObject::removeFromNickCompletionModel(QString id)
@@ -531,7 +544,7 @@ void GlobalObject::removeFromNickCompletionModel(QString id)
     qDebug() << "GlobalObject::removeFromNickCompletionModel()" << id;
 
     QList<QStandardItem *> allNicks;
-    allNicks = nickCompletionModel->findItems(QString(), Qt::MatchContains);
+    allNicks = m_nickCompletionModel->findItems(QString(), Qt::MatchContains);
 
     foreach (QStandardItem *item, allNicks)
     {
@@ -539,7 +552,7 @@ void GlobalObject::removeFromNickCompletionModel(QString id)
 
         if (item->data(Qt::UserRole + 1).toString() == id)
         {
-            int rowNum = item->row();
+            const int rowNum = item->row();
             /*
              * FIXME: Ensure deleting the item is not needed.
              * Deleting it before removeRow doesn't seem to do any harm.
@@ -548,7 +561,7 @@ void GlobalObject::removeFromNickCompletionModel(QString id)
              *
              * delete item;
              */
-            this->nickCompletionModel->removeRow(rowNum);
+            m_nickCompletionModel->removeRow(rowNum);
         }
     }
 }
@@ -556,12 +569,12 @@ void GlobalObject::removeFromNickCompletionModel(QString id)
 void GlobalObject::clearNickCompletionModel()
 {
     // clear() seems to delete the items properly
-    this->nickCompletionModel->clear();
+    m_nickCompletionModel->clear();
 }
 
 void GlobalObject::sortNickCompletionModel()
 {
-    this->filterCompletionModel->sort(0);
+    m_filterCompletionModel->sort(0);
 }
 
 /*
@@ -572,15 +585,15 @@ void GlobalObject::sortNickCompletionModel()
 QPair<QString, QString> GlobalObject::getDataForNick(QString id)
 {
     QList<QStandardItem *> matchingNicks;
-    matchingNicks = nickCompletionModel->findItems(id, Qt::MatchExactly, 1);
+    matchingNicks = m_nickCompletionModel->findItems(id, Qt::MatchExactly, 1);
     if (matchingNicks.isEmpty())
     {
         // Return basic data for invalid case
         return QPair<QString,QString>(id, QString());
     }
 
-    QStandardItem *item = nickCompletionModel->item(matchingNicks.first()->row(),
-                                                    0);
+    QStandardItem *item = m_nickCompletionModel->item(matchingNicks.first()->row(),
+                                                      0);
     // FIXME: add some error control
 
     return QPair<QString,QString>(item->text(),
@@ -609,13 +622,13 @@ void GlobalObject::logMessage(QString message, QString url)
 void GlobalObject::storeTimelineHeight(int height)
 {
     // Substract some pixels to account for the row of buttons, etc.
-    this->timelineHeight = qMax(height - 80,
-                                50); // Never less than 50, but window should never be that small
+    m_timelineHeight = qMax(height - 80,
+                            50); // Never less than 50, but window should never be that small
 }
 
 int GlobalObject::getTimelineHeight()
 {
-    return this->timelineHeight;
+    return m_timelineHeight;
 }
 
 /*
@@ -659,11 +672,11 @@ QSize GlobalObject::getAvatarSizeForIndex(int index)
 
 void GlobalObject::notifyProgramShutdown()
 {
-    this->programClosing = true;
+    m_programIsClosing = true;
     emit programShuttingDown();
 }
 
 bool GlobalObject::isProgramShuttingDown()
 {
-    return this->programClosing;
+    return m_programIsClosing;
 }
