@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -66,7 +66,7 @@ public:
                                bool showDeleted, bool hideDuplicates,
                                bool jumpToNew, int minorFeedSnippets,
                                int snippetsChars, int snippetsCharsHl,
-                               int mfAvatarIdx, int mfVerbIconType);
+                               int mfAvatarIndex, int mfVerbIconType);
     int getPostsPerPageMain();
     int getPostsPerPageOther();
     bool getShowDeleted();
@@ -82,10 +82,10 @@ public:
 
 
     // Post options
-    void syncPostSettings(int postAvatarIdx, int commentAvatarIdx,
+    void syncPostSettings(int postAvatarIndex, int commentAvatarIndex,
                           bool extendedShares, bool showExtraInfo,
                           bool hlAuthorComments, bool hlOwnComments,
-                          bool postIgnoreSslInImages, bool fullImages);
+                          bool ignoreSslInImages, bool fullImages);
     int getPostAvatarIndex();
     QSize getPostAvatarSize();
     int getCommentAvatarIndex();
@@ -108,20 +108,23 @@ public:
 
     // Privacy options
     void syncPrivacySettings(bool silentFollows, bool silentLists,
-                             bool silentLiking);
+                             bool silentLikes);
     bool getSilentFollows();
     bool getSilentLists();
     bool getSilentLikes();
 
 
     // Notification options
-    void syncNotificationSettings(bool notifyTaskbar);
+    void syncNotificationSettings(bool notifyInTaskbar);
     bool getNotifyInTaskbar();
 
 
     // Tray options
-    void syncTrayOptions(bool hideInTrayStartup);
-    bool getHideInTray();
+    void syncTrayOptions(int trayIconType, QString trayIconFN,
+                         bool trayHideStartup);
+    int getTrayIconType();
+    QString getTrayIconFilename();
+    bool getTrayHideOnStartup();
 
 
     ///////////////////////////////////////////////////////////////////////////
@@ -147,7 +150,7 @@ public:
     QPair<QString,QString> getDataForNick(QString id);
 
     void setStatusMessage(QString message);
-    void logMessage(QString message, QString url="");
+    void logMessage(QString message, QString url=QString());
 
     void storeTimelineHeight(int height);
     int getTimelineHeight();
@@ -174,6 +177,7 @@ signals:
 
     void programShuttingDown();
 
+
 public slots:
 
 
@@ -184,73 +188,76 @@ private:
 
 
     // Font options
-    QString postTitleFontInfo;
-    QString postContentsFontInfo;
-    QString commentsFontInfo;
-    QString minorFeedFontInfo;
+    QString m_postTitleFontInfo;
+    QString m_postContentsFontInfo;
+    QString m_commentsFontInfo;
+    QString m_minorFeedFontInfo;
 
 
     // Color options
-    QStringList colorsList;
+    QStringList m_colorsList;
 
 
     // Timeline options
-    int postsPerPageMain;
-    int postsPerPageOther;
-    bool showDeletedPosts;
-    bool hideDuplicatedPosts;
-    bool jumpToNewOnUpdate;
-    int minorFeedSnippetsType;
-    int snippetsCharLimit;
-    int snippetsCharLimitHl;
-    int mfAvatarIndex;
-    QSize mfAvatarSize;
-    int mfIconType;
+    int m_postsPerPageMain;
+    int m_postsPerPageOther;
+    bool m_showDeletedPosts;
+    bool m_hideDuplicatedPosts;
+    bool m_jumpToNewOnUpdate;
+    int m_minorFeedSnippetsType;
+    int m_snippetsCharLimit;
+    int m_snippetsCharLimitHl;
+    int m_mfAvatarIndex;
+    QSize m_mfAvatarSize;
+    int m_mfIconType;
 
 
     // Post options
-    int postAvatarIndex;
-    QSize postAvatarSize;
-    int commentAvatarIndex;
-    QSize commentAvatarSize;
-    bool postExtendedShares;
-    bool postShowExtraInfo;
-    bool postHLAuthorComments;
-    bool postHLOwnComments;
-    bool postIgnoreSslInImages;
-    bool postFullImages;
+    int m_postAvatarIndex;
+    QSize m_postAvatarSize;
+    int m_commentAvatarIndex;
+    QSize m_commentAvatarSize;
+    bool m_postExtendedShares;
+    bool m_postShowExtraInfo;
+    bool m_postHLAuthorComments;
+    bool m_postHLOwnComments;
+    bool m_postIgnoreSslInImages;
+    bool m_postFullImages;
 
 
     // Composer options
-    bool publicPostsByDefault;
-    bool useFilenameAsTitle;
-    bool showCharacterCounter;
+    bool m_publicPostsByDefault;
+    bool m_useFilenameAsTitle;
+    bool m_showCharacterCounter;
 
 
     // Privacy options
-    bool silentFollowing;
-    bool silentListsHandling;
-    bool silentLiking;
+    bool m_silentFollowing;
+    bool m_silentListsHandling;
+    bool m_silentLiking;
 
 
     // Notification options
-    bool notifyInTaskbar;
+    bool m_notifyInTaskbar;
 
 
     // Tray options
-    bool hideInTray;
+    int m_systrayIconType;
+    QString m_systrayIconFN;
+    bool m_systrayHideStartup;
 
 
     //////////////////////////////////////////////////////////////////////////
 
+
     // Other stuff
-    QString dataDirectory;
+    QString m_dataDirectory;
 
-    QStandardItemModel *nickCompletionModel;
-    QSortFilterProxyModel *filterCompletionModel;
-    int timelineHeight;
+    QStandardItemModel *m_nickCompletionModel;
+    QSortFilterProxyModel *m_filterCompletionModel;
+    int m_timelineHeight;
 
-    bool programClosing;
+    bool m_programIsClosing;
 };
 
 #endif // GLOBALOBJECT_H
