@@ -22,12 +22,14 @@ signals:
     void zoomOutRequested();
 
     void zoomableModeRequested();
+    void doubleClicked();
 
 
 public slots:
 
 protected:
     virtual void wheelEvent(QWheelEvent *event);
+    virtual void mouseDoubleClickEvent(QMouseEvent *event);
 
 
 private:
