@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -35,8 +35,8 @@ ListsManager::ListsManager(PumpController *pumpController,
     // To show the current lists
     m_listsTreeWidget = new QTreeWidget(this);
     m_listsTreeWidget->setColumnCount(2);
-    m_listsTreeWidget->setHeaderLabels(QStringList() << tr("Name")
-                                                     << tr("Members"));
+    m_listsTreeWidget->setHeaderLabels(QStringList{ tr("Name"),
+                                                    tr("Members") });
     m_listsTreeWidget->setSortingEnabled(true);
     m_listsTreeWidget->sortByColumn(0, Qt::AscendingOrder);
     m_listsTreeWidget->setAlternatingRowColors(true);
