@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -47,12 +47,12 @@ void customMessageHandler(QtMsgType type,
 int main(int argc, char *argv[])
 {
     QApplication dianaraApp(argc, argv);
-    dianaraApp.setApplicationName("Dianara");
-    dianaraApp.setApplicationVersion("1.4.1");
-    dianaraApp.setOrganizationName("JanCoding");
-    dianaraApp.setOrganizationDomain("jancoding.wordpress.com");
+    dianaraApp.setApplicationName(QStringLiteral("Dianara"));
+    dianaraApp.setApplicationVersion(QStringLiteral("1.4.2"));
+    dianaraApp.setOrganizationName(QStringLiteral("JanCoding"));
+    dianaraApp.setOrganizationDomain(QStringLiteral("jancoding.wordpress.com"));
 
-    std::cout << QString("Dianara v%1 - JanKusanagi 2012-2017\n"
+    std::cout << QString("Dianara v%1 - JanKusanagi 2012-2018\n"
                          "https://jancoding.wordpress.com/dianara\n\n")
                  .arg(dianaraApp.applicationVersion())
                  .toStdString();
@@ -73,8 +73,10 @@ int main(int argc, char *argv[])
 #endif
     std::cout << "\n";
 
-    std::cout << QString("- Running with Qt v%1\n\n").arg(qVersion())
-                                                     .toStdString();
+    std::cout << QString("- Running with Qt v%1\n").arg(qVersion())
+                                                   .toStdString();
+    std::cout << QString("- Qt Platform plugin in use: %1\n\n")
+                 .arg(qApp->platformName()).toStdString();
     std::cout.flush();
 
 
