@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -71,8 +71,8 @@ MinorFeedItem::MinorFeedItem(ASActivity *activity,
                                   .arg(generator));
     }
 
-    QString toField = activity->getToString();
-    QString ccField = activity->getCCString();
+    const QString toField = activity->getToString();
+    const QString ccField = activity->getCcString();
     if (!toField.isEmpty() || !ccField.isEmpty())
     {
         timestampTooltip.append("<br>"); // Extra separation before To or Cc
