@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -202,47 +202,46 @@ bool MiscHelpers::isImageAnimated(QString fileUri)
 QStringList MiscHelpers::iconsForActivity(QString verb)
 {
     QVariantMap iconMap;
-    iconMap.insert("like",            QStringList("emblem-favorite")
-                                       << ":/images/button-like.png");
-    iconMap.insert("unlike",          QStringList("emblem-favorite")
-                                       << ":/images/button-like.png");
-    iconMap.insert("favorite",        QStringList("emblem-favorite")
-                                       << ":/images/button-like.png");
-    iconMap.insert("unfavorite",      QStringList("emblem-favorite")
-                                       << ":/images/button-like.png");
+    iconMap.insert("like",            QStringList{ "emblem-favorite",
+                                                   ":/images/button-like.png" });
+    iconMap.insert("unlike",          QStringList{ "emblem-favorite",
+                                                   ":/images/button-like.png" });
+    iconMap.insert("favorite",        QStringList{ "emblem-favorite",
+                                                   ":/images/button-like.png" });
+    iconMap.insert("unfavorite",      QStringList{ "emblem-favorite",
+                                                   ":/images/button-like.png" });
 
-    iconMap.insert("unshare",         QStringList("dialog-cancel")
-                                       << ":/images/button-cancel.png");
+    iconMap.insert("unshare",         QStringList{ "dialog-cancel",
+                                                   ":/images/button-cancel.png" });
 
-    iconMap.insert("post",            QStringList("mail-send")
-                                       << ":/images/button-post.png");
+    iconMap.insert("post",            QStringList{ "mail-send",
+                                                   ":/images/button-post.png" });
 
-    iconMap.insert("update",          QStringList("view-refresh")
-                                       << ":/images/menu-refresh.png");
+    iconMap.insert("update",          QStringList{ "view-refresh",
+                                                   ":/images/menu-refresh.png" });
 
-    iconMap.insert("follow",          QStringList("list-add-user")
-                                       << ":/images/list-add.png");
-    iconMap.insert("stop-following",  QStringList("list-remove-user")
-                                       << ":/images/list-remove.png");
+    iconMap.insert("follow",          QStringList{ "list-add-user",
+                                                   ":/images/list-add.png" });
+    iconMap.insert("stop-following",  QStringList{ "list-remove-user",
+                                                   ":/images/list-remove.png" });
 
-    iconMap.insert("add",             QStringList("list-add")
-                                       << ":/images/list-add.png");
-    iconMap.insert("remove",          QStringList("list-remove")
-                                       << ":/images/list-remove.png");
+    iconMap.insert("add",             QStringList{ "list-add",
+                                                   ":/images/list-add.png" });
+    iconMap.insert("remove",          QStringList{ "list-remove",
+                                                   ":/images/list-remove.png" });
 
-    iconMap.insert("create",         QStringList("document-new") // FIXME; also -edit?
-                                      << ":/images/button-edit.png");
-    iconMap.insert("delete",         QStringList("edit-delete")
-                                      << ":/images/button-delete.png");
+    iconMap.insert("create",         QStringList{ "document-new", // FIXME; also -edit?
+                                                  ":/images/button-edit.png" });
+    iconMap.insert("delete",         QStringList{ "edit-delete",
+                                                  ":/images/button-delete.png" });
 
-    iconMap.insert("join",           QStringList("user-group-new")
-                                      << ":/images/button-online.png");
-    iconMap.insert("leave",          QStringList("user-group-delete")
-                                      << ":/images/button-close.png");
+    iconMap.insert("join",           QStringList{ "user-group-new",
+                                                  ":/images/button-online.png" });
+    iconMap.insert("leave",          QStringList{ "user-group-delete",
+                                                  ":/images/button-close.png" });
 
-    QStringList missingIconList;
-    missingIconList.append("dialog-information");
-    missingIconList.append(":/images/image-missing.png");
+    const QStringList missingIconList = QStringList{ "dialog-information",
+                                                     ":/images/image-missing.png" };
 
 
     return iconMap.value(verb, missingIconList).toStringList();
@@ -251,21 +250,21 @@ QStringList MiscHelpers::iconsForActivity(QString verb)
 
 const QStringList MiscHelpers::imageExtensions()
 {
-    return QStringList() << "png" << "jpg"  << "jpeg" << "jpe" << "gif"
-                         << "mng" << "webp" << "svg";
+    return QStringList{ "png", "jpg", "jpeg", "jpe", "gif",
+                        "mng", "webp", "svg" };
 }
 
 const QStringList MiscHelpers::audioExtensions()
 {
-    return QStringList() << "ogg" << "oga"  << "flac" << "opus" << "mka"
-                         << "mp3" << "mpga" << "wav"  << "wma"  << "asf" ;
+    return QStringList{ "ogg", "oga",  "flac", "opus", "mka",
+                        "mp3", "mpga", "wav",  "wma",  "asf" };
 }
 
 const QStringList MiscHelpers::videoExtensions()
 {
-    return QStringList() << "mkv" << "mpg" << "mpeg" << "mpe" << "mpv"
-                         << "ogm" << "ogg" << "mp4"  << "avi" << "webm"
-                         << "mov" << "flv" << "3gp"  << "wmv" << "asf";
+    return QStringList{ "mkv", "mpg", "mpeg", "mpe", "mpv",
+                        "ogm", "ogg", "mp4",  "avi", "webm",
+                        "mov", "flv", "3gp",  "wmv", "asf" };
 }
 
 /*
@@ -317,12 +316,12 @@ QString MiscHelpers::fileSizeString(QString fileURI)
     if (fileSize > 1024) // if > 1024 bytes, transform to KiB
     {
         fileSize /= 1024.0;
-        sizeUnit = "KiB";
+        sizeUnit = QStringLiteral("KiB");
     }
     if (fileSize > 1024) // if > 1024 KiB, transform to MiB
     {
         fileSize /= 1024.0;
-        sizeUnit = "MiB";
+        sizeUnit = QStringLiteral("MiB");
     }
 
 
@@ -354,7 +353,7 @@ QString MiscHelpers::resolutionString(int width, int height)
 QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWidth)
 {
     // if no <img tag is found, just return the original HTML
-    if (!originalHtml.contains("<img", Qt::CaseInsensitive))
+    if (!originalHtml.contains(QStringLiteral("<img"), Qt::CaseInsensitive))
     {
         //qDebug() << "MiscHelpers::htmlWithReplacedImages(); HTML does NOT contain <img> tags...";
         return QStringList(originalHtml);
@@ -362,12 +361,12 @@ QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWi
 
     //qDebug() << "MiscHelpers::htmlWithReplacedImages(); HTML contains some <img> tags...";
     QString newHtml = originalHtml;
-    newHtml.remove("\n"); // Remove in case misbehaving applications added any
+    newHtml.remove(QStringLiteral("\n")); // Remove in case misbehaving applications added any
 
     QStringList imageList;
     QString imgSrc;
 
-    QRegExp regExp("\\<img(.+)src=(\"|\\')([^\"\\']+)(\"|\\')(.*)\\>");
+    QRegExp regExp(QStringLiteral("\\<img(.+)src=(\"|\\')([^\"\\']+)(\"|\\')(.*)\\>"));
     regExp.setMinimal(true);
 
     int matchedLength = 0;
@@ -402,37 +401,45 @@ QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWi
         // add to the list, and replace HTML
         if (!imgSrc.isEmpty())
         {
-            // If the url had parameters, they _might_ have &amp; in place of "&"
-            imgSrc.replace("&amp;", "&"); // Put them back
+            // If the URL had parameters, they _might_ have &amp; in place of "&"
+            imgSrc.replace(QStringLiteral("&amp;"),
+                           QStringLiteral("&"));   // Put them back
 
             // Check if http part (scheme) is missing from URL, and add it
-            if (!imgSrc.startsWith("http"))
+            if (!imgSrc.startsWith(QStringLiteral("http")))
             {
-                imgSrc.prepend("http:");
+                imgSrc.prepend(QStringLiteral("http:"));
             }
 
             // Add URL to list
             imageList.append(imgSrc);
 
-            QString cachedImageFilename = getCachedImageFilename(imgSrc);
+            const QString cachedImageFilename = getCachedImageFilename(imgSrc);
 
+
+            // Determine optimal image size
             int imageWidth = getImageWidth(cachedImageFilename);
             if (imageWidth <= 0) // If we still don't have a cached file,
             {
-                imageWidth = 32; // set a typical icon size
+                imageWidth = 64; // Set a typical icon size
             }
 
             // If width is bigger than the post, make it smaller to fit
             if (imageWidth > postWidth - 32)
             {
                 // Some margins, to account for a scrollbar or a tab space before the image
+                // FIXME
                 imageWidth = postWidth - 32;
             }
 
+
             newHtml.replace(stringPos,
                             matchedLength,
-                            "<img src=\"" + cachedImageFilename +  "\" "
-                            "width=\"" + QString("%1").arg(imageWidth) + "\" />");
+                            QStringLiteral("<img src=\"")
+                            + cachedImageFilename
+                            + QStringLiteral("\" width=\"")
+                            + QString("%1").arg(imageWidth)
+                            + QStringLiteral("\" />"));
         }
 
         stringPos += matchedLength; // FIXME: error control
@@ -453,25 +460,26 @@ QString MiscHelpers::cleanupHtml(QString originalHtml)
 {
     QString cleanHtml = originalHtml;
 
-    cleanHtml.replace("\n", " ");  // Remove line breaks, as that results in server error 500
+    // Remove line breaks, as that results in server error 500
+    cleanHtml.replace(QStringLiteral("\n"), QStringLiteral(" "));
 
 
-    QRegExp doctypeRE("<!DOCTYPE.*>");
+    QRegExp doctypeRE(QStringLiteral("<!DOCTYPE.*>"));
     doctypeRE.setMinimal(true);
     cleanHtml.remove(doctypeRE);
 
-    QRegExp headRE("<html><head>.*</head>");
+    QRegExp headRE(QStringLiteral("<html><head>.*</head>"));
     headRE.setMinimal(true);
     cleanHtml.remove(headRE);
 
-    QRegExp bodyRE("<body style.*>");
+    QRegExp bodyRE(QStringLiteral("<body style.*>"));
     bodyRE.setMinimal(true);
     cleanHtml.remove(bodyRE);
 
     //////////////////////////////////////// Remove <span style=...> from links
-    QRegExp linkStyleRE("<a href=.*>.*</a>");
+    QRegExp linkStyleRE(QStringLiteral("<a href=.*>.*</a>"));
     linkStyleRE.setMinimal(true);
-    QRegExp spanRE("<span style=.*>(.*)</span>"); // FIXME: remove ONLY color info
+    QRegExp spanRE(QStringLiteral("<span style=.*>(.*)</span>")); // FIXME: remove ONLY color info
     spanRE.setMinimal(true);
 
     int pos = 0;
@@ -490,26 +498,26 @@ QString MiscHelpers::cleanupHtml(QString originalHtml)
     }
 
     ////////////////////////////////////// Remove style from <ul> <ol> and <li>
-    QRegExp ulStyleRE("<ul style.*>");
+    QRegExp ulStyleRE(QStringLiteral("<ul style.*>"));
     ulStyleRE.setMinimal(true);
-    cleanHtml.replace(ulStyleRE, "<ul>");
+    cleanHtml.replace(ulStyleRE, QStringLiteral("<ul>"));
 
-    QRegExp olStyleRE("<ol style.*>");
+    QRegExp olStyleRE(QStringLiteral("<ol style.*>"));
     olStyleRE.setMinimal(true);
-    cleanHtml.replace(olStyleRE, "<ol>");
+    cleanHtml.replace(olStyleRE, QStringLiteral("<ol>"));
 
-    QRegExp liStyleRE("<li style.*>");
+    QRegExp liStyleRE(QStringLiteral("<li style.*>"));
     liStyleRE.setMinimal(true);
-    cleanHtml.replace(liStyleRE, "<li>");
+    cleanHtml.replace(liStyleRE, QStringLiteral("<li>"));
 
 
     // FIXME: Maybe try to remove background colors from <p> elements
 
     // Remove these elements created by some QTextBlocks
-    cleanHtml.remove("<!--StartFragment-->");
-    cleanHtml.remove("<!--EndFragment-->");
+    cleanHtml.remove(QStringLiteral("<!--StartFragment-->"));
+    cleanHtml.remove(QStringLiteral("<!--EndFragment-->"));
 
-    cleanHtml.remove("</body></html>");
+    cleanHtml.remove(QStringLiteral("</body></html>"));
 
     return cleanHtml.trimmed();
 }
@@ -522,12 +530,12 @@ QString MiscHelpers::htmlWithoutLinks(QString originalHtml)
 {
     QString cleanHtml = originalHtml;
 
-    QRegExp linksRE("<a href=.*>");
+    QRegExp linksRE(QStringLiteral("<a href=.*>"));
     linksRE.setMinimal(true);
     linksRE.setCaseSensitivity(Qt::CaseInsensitive);
     cleanHtml.remove(linksRE);
 
-    cleanHtml.remove("</a>", Qt::CaseInsensitive);
+    cleanHtml.remove(QStringLiteral("</a>"), Qt::CaseInsensitive);
 
 
     return cleanHtml;
@@ -539,12 +547,12 @@ QString MiscHelpers::htmlToPlainText(QString html, int charLimit)
     textDocument.setHtml(html);
 
     QString plainText = textDocument.toPlainText().trimmed();
-    plainText.replace("\n", " ");
+    plainText.replace(QStringLiteral("\n"), QStringLiteral(" "));
     plainText = plainText.trimmed();
 
     if (charLimit != 0 && plainText.length() > charLimit)
     {
-        plainText = plainText.left(charLimit).trimmed() + "...";
+        plainText = plainText.left(charLimit).trimmed() + QStringLiteral("...");
     }
 
     return plainText;
@@ -626,7 +634,7 @@ QString MiscHelpers::mediaHtmlBase(QString postType,
                    "<td align=center>"
                    "<a title=\"" + tooltipMessage + "\" href";
 
-    if (postType == "image")
+    if (postType == QStringLiteral("image"))
     {
         html.append("=\"image:/" + attachmentFilename + "\" >");
     }
