@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -203,9 +203,10 @@ void FDNotifications::showMessage(QString message)
         arguments << QStringLiteral("dialog-information");
     }
 
-    QStringList actions; // Handled on MainWindow::onNotificationAction()
-    actions << QString("dianara_%1_show").arg(qApp->applicationPid())
-            << tr("Show");
+    // Notification button handled on MainWindow::onNotificationAction()
+    const QStringList actions = QStringList{
+                                 QString("dianara_%1_show").arg(qApp->applicationPid()),
+                                 tr("Show") }; // Could use "default" as ID, and no visible name
     arguments << notificationTitle;
     arguments << message;
     arguments << actions;
