@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -107,6 +107,10 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
     connect(m_closeButton, &QAbstractButton::clicked,
             this, &QWidget::hide);
 
+    m_bottomButtonBox = new QDialogButtonBox(this);
+    m_bottomButtonBox->addButton(m_goButton,    QDialogButtonBox::AcceptRole);
+    m_bottomButtonBox->addButton(m_closeButton, QDialogButtonBox::RejectRole);
+
 
     m_closeAction = new QAction(this);
     m_closeAction->setShortcut(QKeySequence(Qt::Key_Escape));
@@ -136,12 +140,6 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
     m_middleLayout->addWidget(m_olderButton);
 
 
-    m_bottomLayout = new QHBoxLayout();
-    m_bottomLayout->setAlignment(Qt::AlignRight);
-    m_bottomLayout->addWidget(m_goButton);
-    m_bottomLayout->addWidget(m_closeButton);
-
-
     m_mainLayout = new QVBoxLayout();
     m_mainLayout->addLayout(m_topLayout);
     m_mainLayout->addSpacing(24);
@@ -149,7 +147,7 @@ PageSelector::PageSelector(QWidget *parent) : QWidget(parent)
     m_mainLayout->addLayout(m_middleLayout);
     m_mainLayout->addStretch(2);
     m_mainLayout->addSpacing(32);
-    m_mainLayout->addLayout(m_bottomLayout);
+    m_mainLayout->addWidget(m_bottomButtonBox);
     this->setLayout(m_mainLayout);
 
     qDebug() << "PageSelector created";
