@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -177,114 +177,110 @@ protected:
 
 
 private:
-    QHBoxLayout *mainLayout;
-    QVBoxLayout *leftColumnLayout;
-    QVBoxLayout *rightColumnLayout;
-    QVBoxLayout *outerLayout;
+    QHBoxLayout *m_mainLayout;
+    QVBoxLayout *m_leftColumnLayout;
+    QVBoxLayout *m_rightColumnLayout;
+    QVBoxLayout *m_outerLayout;
 
-    QFrame *leftColumnFrame;
-    QFrame *rightColumnFrame;
+    QFrame *m_leftColumnFrame;
+    QFrame *m_rightColumnFrame;
 
-    QString activityId;
-    QString postId;
-    QString postType;
-    QString postUrl;
-    QString postAuthorId;
-    QString postAuthorName;
+    QString m_activityId;
+    QString m_postId;
+    QString m_postType;
+    QString m_postUrl;
+    QString m_postAuthorId;
+    QString m_postAuthorName;
 
-    QString postSharedById;
-    QString postShareInfoString;
-    QString postSharedToCCString;
-    QString postShareTime;
+    QString m_postShareInfoString;
+    QString m_postSharedToCcString;
+    QString m_postShareTime;
 
-    bool postIsOwn;
-    bool postIsUnread;
-    bool postIsDeleted;
-    int highlightType;
-    QString unreadPostColor;
+    bool m_postIsOwn;
+    bool m_postIsUnread;
+    bool m_postIsDeleted;
+    int m_highlightType;
+    QString m_unreadPostColor;
 
-    AvatarButton *postAuthorAvatarButton;
-    QAction *openPostInBrowserAction;
-    QAction *copyPostUrlAction;
-    QAction *normalizeTextAction;
-    QAction *closeAction;
+    AvatarButton *m_postAuthorAvatarButton;
+    QAction *m_openInBrowserAction;
+    QAction *m_copyPostUrlAction;
+    QAction *m_normalizeTextAction;
+    QAction *m_closeAction;
 
-    QLabel *postAuthorNameLabel;
-    HClabel *postCreatedAtLabel;
-    QLabel *postGeneratorLabel;
-    HClabel *postLocationLabel;
-    QLabel *postToLabel;
-    QLabel *postCCLabel;
-    QLabel *postIsSharedLabel;
-    QLabel *shareHintLabel;
+    QLabel *m_authorLabel;
+    HClabel *m_timestampLabel;
+    QLabel *m_generatorLabel;
+    HClabel *m_locationLabel;
+    QLabel *m_toLabel;
+    QLabel *m_ccLabel;
+    QLabel *m_shareInfoLabel;
+    QLabel *m_shareHintLabel;
 
-    HClabel *postLikesCountLabel;
-    QLabel *postCommentsCountLabel;
-    HClabel *postSharesCountLabel;
+    HClabel *m_likesCountLabel;
+    QLabel *m_commentsCountLabel;
+    HClabel *m_sharesCountLabel;
 
-    QPushButton *openParentPostButton;
+    QPushButton *m_openParentButton;
 
-    //QPushButton *closeButton;
+    QLabel *m_titleLabel;
+    QLabel *m_summaryLabel;
+    QTextBrowser *m_bodyTextBrowser;
 
-    QLabel *postTitleLabel;
-    QLabel *postSummaryLabel;
-    QTextBrowser *postText;
+    QHBoxLayout *m_buttonsLayout;
+    QPushButton *m_likeButton;
+    QPushButton *m_commentButton;
+    QPushButton *m_shareButton;
+    QPushButton *m_editButton;
+    QPushButton *m_deleteButton;
 
-    QHBoxLayout *buttonsLayout;
-    QPushButton *likeButton;
-    QPushButton *commentButton;
-    QPushButton *shareButton;
+    QPushButton *m_joinLeaveButton;
+    QLabel *m_groupInfoLabel;
 
-    QPushButton *editButton;
-    QPushButton *deleteButton;
+    DownloadWidget *m_downloadWidget;
+    bool m_haveDownloadWidget;
 
-    QPushButton *joinLeaveButton;
-    QLabel *groupInfoLabel;
+    FilterMatchesWidget *m_filterMatchesWidget;
 
-    DownloadWidget *downloadWidget;
+    QString m_postTitle;
+    QString m_postFullImageUrl;
+    QString m_postImageUrl;
+    QSize m_postImageSize;
+    bool m_postImageIsAnimated;
+    bool m_postImageFailed;
+    QString m_postAudioUrl;
+    QString m_postVideoUrl;
+    QString m_postFileUrl;
+    QString m_postFileMimeType;
+    QString m_postAttachmentPureUrl;
+    QString m_postOriginalText;
+    QVariantMap m_postParentMap;
 
-    FilterMatchesWidget *filterMatchesWidget;
+    QString m_timeCreatedAtString;
+    QString m_timeUpdatedAtString;
+    QString m_generatorString;
 
-    QString postTitle;
-    QString postSmallImageUrl;
-    QString postFullImageUrl;
-    QString postImageUrl;
-    QSize postImageSize;
-    bool postImageIsAnimated;
-    bool postImageFailed;
-    QString postAudioUrl;
-    QString postVideoUrl;
-    QString postFileUrl;
-    QString postFileMimeType;
-    QString postAttachmentPureUrl;
-    QString postOriginalText;
-    QVariantMap postParentMap;
+    int m_postWidth;
 
-    QString postCreatedAtString;
-    QString postUpdatedAtString;
-    QString postGeneratorString;
-
-    int postWidth;
-
-    QString postLikesUrl;
-    int postLikesCount;
-    QVariantMap postLikesMap;
-    QString postCommentsUrl;
-    QString postSharesUrl;
+    QString m_likesUrl;
+    int m_likesCount;
+    QVariantMap m_likesMap;
+    QString m_commentsUrl;
+    QString m_sharesUrl;
 
 
-    QStringList pendingImagesList;
+    QStringList m_pendingImagesList;
 
-    bool standalone;
+    bool m_standalone;
 
-    QString seeFullImageString;
-    QString downloadAttachmentString;
+    QString m_seeFullImageString;
+    QString m_downloadAttachmentString;
 
-    QTimer *resizeTimer;
+    QTimer *m_resizeTimer;
 
-    PumpController *pController;
-    GlobalObject *globalObj;
-    CommenterBlock *commenter;
+    PumpController *m_pumpController;
+    GlobalObject *m_globalObject;
+    CommenterBlock *m_commenterBlock;
 };
 
 #endif // POST_H
