@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -135,6 +135,11 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     connect(m_cancelButton, &QAbstractButton::clicked,
             this, &QWidget::close);
 
+    // Buttons managed via DBB to have proper order on each desktop environment
+    m_buttonBox = new QDialogButtonBox(this);
+    m_buttonBox->addButton(m_saveButton, QDialogButtonBox::AcceptRole);
+    m_buttonBox->addButton(m_cancelButton, QDialogButtonBox::RejectRole);
+
 
     // ESC to cancel, too
     m_cancelAction = new QAction(this);
@@ -169,17 +174,10 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     // FIXME: the FormLayout doesn't let the bioTextEdit row grow taller than its sizeHint()
 
 
-    m_bottomLayout = new QHBoxLayout();
-    m_bottomLayout->setAlignment(Qt::AlignRight | Qt::AlignBottom);
-    m_bottomLayout->setContentsMargins(0, 0, 0, 0);
-    m_bottomLayout->addWidget(m_saveButton);
-    m_bottomLayout->addWidget(m_cancelButton);
-
-
     m_mainLayout = new QVBoxLayout();
-    m_mainLayout->addLayout(m_topLayout,     9);
+    m_mainLayout->addLayout(m_topLayout, 9);
     m_mainLayout->addWidget(m_newAvatarInfoLabel);
-    m_mainLayout->addLayout(m_bottomLayout,  1);
+    m_mainLayout->addWidget(m_buttonBox, 1);
     this->setLayout(m_mainLayout);
 
 
