@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -28,6 +28,7 @@
 #include <QLineEdit>
 #include <QTextEdit>
 #include <QPushButton>
+#include <QDialogButtonBox>
 #include <QFileDialog>
 #include <QMessageBox>
 #include <QAction>
@@ -78,7 +79,6 @@ private:
     QFormLayout *m_topLayout;
     QHBoxLayout *m_emailLayout;
     QHBoxLayout *m_avatarLayout;
-    QHBoxLayout *m_bottomLayout;
 
     QLabel *m_webfingerLabel;
 
@@ -98,6 +98,7 @@ private:
 
     QPushButton *m_saveButton;
     QPushButton *m_cancelButton;
+    QDialogButtonBox *m_buttonBox;
 
     QAction *m_cancelAction;
 
