@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -118,6 +118,7 @@ Publisher::Publisher(PumpController *pumpController,
 
 
     m_uploadProgressBar = new QProgressBar(this);
+    m_uploading = false;
 
 
     // Set default pixmap and "media not set" message
@@ -938,6 +939,19 @@ void Publisher::setMinimumMode()
     // Re-enable stuff just in case the POST request never finished
     this->toggleWidgetsWhileSending(true);
 
+    if (m_uploading)
+    {
+        qDebug() << "Aborting ongoing upload...";
+        // Should use m_uploadNetworkReply->abort(), but that causes
+        // PumpController to report error and set Publisher to "posting failed"
+        m_uploadNetworkReply->deleteLater();
+        m_uploading = false; // Need to set it manually since the connect()s
+                             // for the QNetworkReply are gone at this point
+
+        m_pumpController->showStatusMessageAndLogIt(tr("Attachment upload "
+                                                       "was cancelled."));
+    }
+
 #ifdef GROUPSUPPORT
     m_groupIdLabel->hide();
     m_groupIdLineEdit->hide();
@@ -1587,6 +1601,7 @@ void Publisher::sendPost()
             }
             else
             {
+                m_uploading = true;
                 m_uploadNetworkReply = m_pumpController->postMedia(audienceMap,
                                                                    cleanHtmlString,
                                                                    postTitle,
@@ -1595,8 +1610,10 @@ void Publisher::sendPost()
                                                                    m_mediaContentType);
                 connect(m_uploadNetworkReply, &QNetworkReply::uploadProgress,
                         this, &Publisher::updateProgressBar);
-                // This will be automatically disconnected when
-                // the QNetworkReply is automatically deleted!
+                connect(m_uploadNetworkReply, &QNetworkReply::finished,
+                        this, &Publisher::onUploadFinished);
+                // These will be automatically disconnected when
+                // the QNetworkReply is automatically deleted
 
                 // The "remove" button uses the same space as the progress bar
                 m_removeMediaButton->hide();
@@ -1657,6 +1674,12 @@ void Publisher::updateProgressBar(qint64 sent, qint64 total)
                                                  .toString(total / 1024)));
 }
 
+void Publisher::onUploadFinished()
+{
+    qDebug() << "File upload finished in some way";
+    m_uploading = false;
+}
+
 
 void Publisher::updateCharacterCounter()
 {
