@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -120,6 +120,7 @@ public slots:
 
     void onSelectMediaFilePressed();
     void updateProgressBar(qint64 sent, qint64 total);
+    void onUploadFinished();
 
     void updateCharacterCounter();
 
@@ -192,6 +193,7 @@ private:
     bool m_fullMode;
 
     QNetworkReply *m_uploadNetworkReply;
+    bool m_uploading;
 
     PumpController *m_pumpController;
     GlobalObject *m_globalObject;
