@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2017  JanKusanagi JRR <jancoding@gmx.com>
+ *   Copyright 2012-2018  JanKusanagi JRR <jancoding@gmx.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -797,7 +797,7 @@ void TimeLine::setTimeLineContents(QVariantList postList, QString previousLink,
 
     // Remove all previous posts in timeline, when switching pages
     if (m_firstLoad || !m_wasOnFirstPage
-     || m_isFavoritesTimeline || m_timelineOffset > 0) // FIXME: this fails in some situations
+     || m_isFavoritesTimeline || m_timelineOffset > 0)
     {
         // Hide the posts while TL reloads; helps performance a lot
         m_postsWidget->hide();
@@ -1350,6 +1350,7 @@ void TimeLine::goToFirstPage()
     this->syncPostsPerPage();
 
     m_gettingNew = true;
+    m_oldTimelineOffset = m_timelineOffset;
 
     if (m_timelineOffset == 0) // On page 1
     {
@@ -1360,7 +1361,6 @@ void TimeLine::goToFirstPage()
         m_wasOnFirstPage = false;
 
         m_previousPageLink.clear();  // Full reload of newest stuff
-        m_oldTimelineOffset = m_timelineOffset;
         m_timelineOffset = 0;
 
         this->setDisabled(true); // Disable soon, to avoid wrong clicks
